<p align="center">
    <em>tap-fabdb, a Singer tap for extracting data from the <a href="https://fabdb.net/resources/api" target="_blank">FaB DB API</a>.</em>
</p>
<p align="center">
  <a href="https://badge.fury.io/py/tap-fabdb">
    <img src="https://badge.fury.io/py/tap-fabdb.svg" alt="PyPI version" height="18">
  </a>
  <a href="https://github.com/dwallace0723/tap-fabdb/actions">
    <img src="https://github.com/dwallace0723/tap-fabdb/actions/workflows/test.yml/badge.svg"  alt="GitHub Actions" />
  </a>
  <a href="https://github.com/dwallace0723/tap-fabdb/actions">
    <img src="https://github.com/dwallace0723/tap-fabdb/actions/workflows/release.yml/badge.svg"  alt="GitHub Actions" />
  </a>
  <a href="https://github.com/dwallace0723/tap-fabdb/actions">
    <img src="https://github.com/dwallace0723/tap-fabdb/actions/workflows/publish.yml/badge.svg"  alt="GitHub Actions" />
  </a>
  <a href="https://codeclimate.com/github/dwallace0723/tap-fabdb/maintainability">
    <img src="https://api.codeclimate.com/v1/badges/875607d70a6dc02a82df/maintainability" />
  </a>
  <a href="https://codeclimate.com/github/dwallace0723/tap-fabdb/test_coverage">
    <img src="https://api.codeclimate.com/v1/badges/875607d70a6dc02a82df/test_coverage" />
  </a>
  <a href="https://github.com/psf/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg"  alt="Black" />
  </a>
</p>